@@ -4,6 +4,7 @@ pub fn line_fill<T: std::fmt::Write>(
     path: &mut tagger::PathBuilder<T>,
     mut it: impl Iterator<Item = [f64; 2]>,
     base_line: f64,
+    add_start_end_base:bool
 ) -> fmt::Result {
     if let Some([startx, starty]) = it.next() {
         use tagger::PathCommand::*;
@@ -18,9 +19,12 @@ pub fn line_fill<T: std::fmt::Write>(
             ) {
                 (true, true) => {
                     if first {
-                        path.put(M(last[0], base_line))?;
-                        path.put(L(last[0], last[1]))?;
-
+                        if add_start_end_base{
+                            path.put(M(last[0], base_line))?;
+                            path.put(L(last[0], last[1]))?;
+                        }else{
+                            path.put(M(last[0], last[1]))?;
+                        }
                         first = false;
                     }
                     last_finite = Some([newx, newy]);
@@ -37,7 +41,9 @@ pub fn line_fill<T: std::fmt::Write>(
             last = [newx, newy];
         }
         if let Some([x, _]) = last_finite {
-            path.put(L(x, base_line))?;
+            if add_start_end_base{
+                path.put(L(x, base_line))?;   
+            }
             path.put(Z(""))?;
         }
     }
@@ -104,7 +110,7 @@ pub(super) fn draw_base<X: PlotNum, Y: PlotNum, T: fmt::Write>(
 
     writer
         .elem("text", |d| {
-            d.attr("class", "poloto_text")?;
+            d.attr("class", "poloto_labels poloto_text poloto_title")?;
             d.attr("alignment-baseline", "start")?;
             d.attr("text-anchor", "middle")?;
             d.attr("font-size", "x-large")?;
@@ -115,7 +121,7 @@ pub(super) fn draw_base<X: PlotNum, Y: PlotNum, T: fmt::Write>(
 
     writer
         .elem("text", |d| {
-            d.attr("class", "poloto_text")?;
+            d.attr("class", "poloto_labels poloto_text poloto_xname")?;
             d.attr("alignment-baseline", "start")?;
             d.attr("text-anchor", "middle")?;
             d.attr("font-size", "x-large")?;
@@ -126,7 +132,7 @@ pub(super) fn draw_base<X: PlotNum, Y: PlotNum, T: fmt::Write>(
 
     writer
         .elem("text", |d| {
-            d.attr("class", "poloto_text")?;
+            d.attr("class", "poloto_labels poloto_text poloto_yname")?;
             d.attr("alignment-baseline", "start")?;
             d.attr("text-anchor", "middle")?;
             d.attr("font-size", "x-large")?;
@@ -165,7 +171,7 @@ pub(super) fn draw_base<X: PlotNum, Y: PlotNum, T: fmt::Write>(
             let extra = if let Some(base) = xtick_info.display_relative {
                 writer
                     .elem("text", |d| {
-                        d.attr("class", "poloto_text")?;
+                        d.attr("class", "poloto_tick_labels poloto_text")?;
                         d.attr("alignment-baseline", "middle")?;
                         d.attr("text-anchor", "start")?;
                         d.attr("x", width * 0.55)?;
@@ -200,7 +206,7 @@ pub(super) fn draw_base<X: PlotNum, Y: PlotNum, T: fmt::Write>(
                 let s = xtick_info.step;
                 writer
                     .elem("text", |d| {
-                        d.attr("class", "poloto_text")?;
+                        d.attr("class", "poloto_tick_labels poloto_text")?;
                         d.attr("alignment-baseline", "start")?;
                         d.attr("text-anchor", "middle")?;
                         d.attr("x", aspect_offset + xx)?;
@@ -221,7 +227,7 @@ pub(super) fn draw_base<X: PlotNum, Y: PlotNum, T: fmt::Write>(
             let extra = if let Some(base) = ytick_info.display_relative {
                 writer
                     .elem("text", |d| {
-                        d.attr("class", "poloto_text")?;
+                        d.attr("class", "poloto_tick_labels poloto_text")?;
                         d.attr("alignment-baseline", "middle")?;
                         d.attr("text-anchor", "start")?;
                         d.attr("x", padding)?;
@@ -258,7 +264,7 @@ pub(super) fn draw_base<X: PlotNum, Y: PlotNum, T: fmt::Write>(
 
                 writer
                     .elem("text", |d| {
-                        d.attr("class", "poloto_text")?;
+                        d.attr("class", "poloto_tick_labels poloto_text")?;
                         d.attr("alignment-baseline", "middle")?;
                         d.attr("text-anchor", "end")?;
                         d.attr("x", aspect_offset + padding - textx_padding)?;
@@ -288,7 +294,6 @@ pub(super) fn draw_base<X: PlotNum, Y: PlotNum, T: fmt::Write>(
                     format_args!(
                         "stroke-dasharray:{};stroke-dashoffset:{};",
                         xdash_size / 2.0,
-                        //-(distance_to_firstx).scale2([minx,maxx],scalex)
                         -distance_to_firstx
                     ),
                 )?;
@@ -320,7 +325,6 @@ pub(super) fn draw_base<X: PlotNum, Y: PlotNum, T: fmt::Write>(
                     format_args!(
                         "stroke-dasharray:{};stroke-dashoffset:{};",
                         ydash_size / 2.0,
-                        //-(distance_to_firsty).scale2([miny,maxy],scaley)
                         -distance_to_firsty
                     ),
                 )?;
